diff lisp/vc-git.el @ 85141:b16f7408cd3f

Carry through today's big terminology change to a few places where I missed it in the back ends.
author Eric S. Raymond <esr@snark.thyrsus.com>
date Wed, 10 Oct 2007 19:39:23 +0000
parents 8ba0e30716a5
children dec6fdd5ddf4
line wrap: on
line diff
--- a/lisp/vc-git.el	Wed Oct 10 19:18:53 2007 +0000
+++ b/lisp/vc-git.el	Wed Oct 10 19:39:23 2007 +0000
@@ -77,11 +77,11 @@
 ;;                                                 wouldn't be identified as a merge by git,
 ;;                                                 so it's probably not a good idea.
 ;; - merge-news (file)				   see `merge'
-;; - steal-lock (file &optional version)	   NOT NEEDED
+;; - steal-lock (file &optional revision)	   NOT NEEDED
 ;; HISTORY FUNCTIONS
 ;; * print-log (files &optional buffer)		   OK
 ;; - log-view-mode ()				   OK
 ;; - show-log-entry (version)			   NOT NEEDED, DEFAULT IS GOOD
 ;; - wash-log (file)				   COULD BE SUPPORTED
 ;; - logentry-check ()				   NOT NEEDED
 ;; - comment-history (file)			   ??
@@ -100,8 +100,8 @@
 ;; MISCELLANEOUS
 ;; - make-version-backups-p (file)		   NOT NEEDED
 ;; - repository-hostname (dirname)		   NOT NEEDED
-;; - previous-version (file rev)		   OK
-;; - next-version (file rev)			   OK
+;; - previous-revision (file rev)		   OK
+;; - next-revision (file rev)			   OK
 ;; - check-headers ()				   COULD BE SUPPORTED
 ;; - clear-headers ()				   NOT NEEDED
 ;; - delete-file (file)				   OK
@@ -372,8 +372,8 @@
 
 ;;; MISCELLANEOUS
 
-(defun vc-git-previous-version (file rev)
-  "Git-specific version of `vc-previous-version'."
+(defun vc-git-previous-revision (file rev)
+  "Git-specific version of `vc-previous-revision'."
   (let ((default-directory (file-name-directory (expand-file-name file)))
 	(file (file-name-nondirectory file)))
     (vc-git-symbolic-commit
@@ -390,8 +390,8 @@
 	   (point)
 	   (1- (point-max))))))))
 
-(defun vc-git-next-version (file rev)
-  "Git-specific version of `vc-next-version'."
+(defun vc-git-next-revision (file rev)
+  "Git-specific version of `vc-next-revision'."
   (let* ((default-directory (file-name-directory
 			     (expand-file-name file)))
 	(file (file-name-nondirectory file))
@@ -77,11 +77,11 @@
 ;; * print-log (files &optional buffer)		   OK
 ;; - log-view-mode ()				   OK
-;; - show-log-entry (version)			   NOT NEEDED, DEFAULT IS GOOD
+;; - show-log-entry (revision)			   NOT NEEDED, DEFAULT IS GOOD
 ;; - wash-log (file)				   COULD BE SUPPORTED
 ;; - logentry-check ()				   NOT NEEDED